package edu.agh.sius.ejb;

import java.util.Date;

import javax.ejb.EntityContext;
import javax.ejb.RemoveException;

public abstract class AbstractEBBean {

	/**
	 * Entity bean context
	 *
	 */
	protected EntityContext entityCtx = null;


	protected Date getToday() {
		return new java.util.Date();
	}

	/**
	 * Default no-arguments constructor
	 */
	public AbstractEBBean() {

	}

	/**
	 * Called by container and never called by client code.
	 * Associates the entity bean with entity bean context.
	 * Once done, it is possible to query entity bean context for some
	 * environment information.
	 *
	 * @param entityCtx entity bean context
	 *
	 * @uml.property name="entityCtx"
	 */
	public void setEntityContext(EntityContext entityCtx) {
		this.entityCtx = entityCtx;
	}

	/**
	 * Called by container and never called by client code.
	 * Disassociates the entity bean with entity bean context.
	 */
	public void unsetEntityContext() {
		this.entityCtx = null;
	}

	/**
	 * Called by container and never called by client code.
	 * Container calls this method right before the entity bean is activated.
	 * Implementation can allocate needed resources.
	 */
	public void ejbActivate() {

	}

	/**
	 * Called by container and never called by client code.
	 * Container calls this method right before the entity bean is passivated.
	 * Implementation can release allocated resources.
	 */
	public void ejbPassivate() {

	}

	/**
	 * Called by container and never called by client code.
	 * Container calls this method right before it
	 * removes the entity bean from the database.
	 * Since we are using CMP entity bean, we can leave this method blank.
	 */
	public void ejbRemove() throws RemoveException {

	}

	/**
	 * Called by container and never called by client code.
	 * Container calls this method right before it 
	 * updates the entity bean to reflect the current value stored in
	 * the database.
	 * Since we are using CMP entity bean, we can leave this method blank.
	 */
	public void ejbLoad() {

	}

	/**
	 * Called by container and never called by client code.
	 * Container calls this method right before it updates the database 
	 * to reflect the current values of this entity bean representation.
	 * Since we are using CMP entity bean, we can leave this method blank.
	 */
	public void ejbStore() {

	}

}
