/**
 * Copyright (c) 2001/2003 Distributed Systems Research Group.
 * All rights reserved.
 *
 * For more information on Distributed Systems Research Group (DSRG),
 * please see <http://www.ics.agh.edu.pl/>.
 *
 * @author radzisz
 * file name: FortuneEJB.java
 *
 */
package edu.agh.sius.ejb;

import java.rmi.RemoteException;

import javax.ejb.CreateException;
import javax.ejb.EJBException;
import javax.ejb.EntityBean;
import javax.ejb.EntityContext;
import javax.ejb.SessionContext;

import edu.agh.sius.ejb.FortuneEBPK;

import org.apache.log4j.Logger;

/**
*  The Entity bean represents a Fortune
*
* @author Dominik Radziszowski
* @version $Revision: 1.5 $
*
* @ejb.bean name="FortuneEB"
*	    display-name="FortuneEntity"
*	    type="CMP"
*	    jndi-name="ejb/fortune/FortuneEB"
*	    reentrant="false"
*	    view-type="local"
*
* @ejb.transaction type="Required"
*
* @ejb.finder signature="java.util.Collection findAll()"
*
* @ejb.persistence table-name ="t_fortune"
* @jboss.create-table create="${create_table}"
* @jboss.remove-table remove="${remove_table}"
**/

public abstract class FortuneCMP extends AbstractEBBean implements EntityBean {

	private static Logger logger =
		Logger.getLogger("edu.agh.sius.fortune");


	// -------------------------------------------------------------------------
	// Methods
	// -------------------------------------------------------------------------


	// -------------------------------------------------------------------------
	// Properties (Getters/Setters)
	// -------------------------------------------------------------------------
	/**
	 * Retrieve the attributeEntity's id.
	 * @return Returns an Integer representing the id of this attributeEntity.
	 *
	 * @ejb.persistent-field
	 * @ejb.persistence column-name="id"
	 * @ejb.pk-field
	 */
	public abstract Integer getId();
	public abstract void setId(Integer id);

	/**
	 * Retrieve the attribute Entity's high treshold.
	 *
	 * @return Returns an int representing high treshold for given attribute.
	 *
	 * @ejb.persistent-field
	 * @ejb.persistence column-name ="text"
	 * @ejb.interface-method view-type="local"
	**/
	public abstract String getText();
	public abstract void setText(String text);

	// -------------------------------------------------------------------------
	// Framework Callbacks
	// -------------------------------------------------------------------------


	/**
	* @ejb.create-method view-type="local"
	**/
	public FortuneEBPK ejbCreate(String text) throws CreateException {
		Integer id = new Integer((int) (Math.random() * 10000));
		//sequencer bean or DB sequence should be used here
		setId(id);
		setText(text);
		logger.info("Creating FortuneEJB with id: " + id + ", text:" + text);
		return null;
	}
}
